@@ -8,7 +8,7 @@
 #define K_GAME_POPUP_ITEM_H
 
 // own
-#include <libkdegames_export.h>
+#include "kdegames_export.h"
 // Qt
 #include <QGraphicsItem>
 #include <QObject>
@@ -181,7 +181,8 @@ private:
     void hoverLeaveEvent(QGraphicsSceneHoverEvent *) override;
 
 private:
-    std::unique_ptr<KGamePopupItemPrivate> const d;
+    std::unique_ptr<KGamePopupItemPrivate> const d_ptr;
+    Q_DECLARE_PRIVATE(KGamePopupItem)
 };
 
 #endif
